==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiGui/QFileOpenEvent_shell.cpp <==
#include "QFileOpenEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QFileOpenEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QFileOpenEvent")
    QFileOpenEvent *_ptr = reinterpret_cast<QFileOpenEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QFileOpenEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QFileOpenEvent_shell) ); }

jmethodID QFileOpenEvent_shell::__shell_javaMethod(int pos) const { return QFileOpenEvent_shell::__shell()->javaMethod(typeid(QFileOpenEvent), pos); }

// emitting (writeShellConstructor)
QFileOpenEvent_shell::QFileOpenEvent_shell(const QString& file0)
    : QFileOpenEvent(file0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QFileOpenEvent::QFileOpenEvent_shell(const QString& file0)", QFileOpenEvent_shell::__shell())
    QFileOpenEvent_shell::__shell()->constructed(typeid(QFileOpenEvent));
}

QFileOpenEvent_shell::QFileOpenEvent_shell(const QUrl& url0)
    : QFileOpenEvent(url0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QFileOpenEvent::QFileOpenEvent_shell(const QUrl& url0)", QFileOpenEvent_shell::__shell())
    QFileOpenEvent_shell::__shell()->constructed(typeid(QFileOpenEvent));
}

// emitting (writeShellDestructor)
QFileOpenEvent_shell::~QFileOpenEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QFileOpenEvent::~QFileOpenEvent()", QFileOpenEvent_shell::__shell())
    QFileOpenEvent_shell::__shell()->destructed(typeid(QFileOpenEvent));
}

void QFileOpenEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QFileOpenEvent_shell*>(ptr)->QFileOpenEvent_shell::__shell()->tryDeleteShell(typeid(QFileOpenEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QFileOpenEvent(QString)
void __qt_construct_QFileOpenEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QFileOpenEvent(QString)")
    jstring file0 = static_cast<jstring>(__java_arguments[0].l);
    QString  __qt_file0 = qtjambi_cast<QString>(__jni_env, file0);
    QFileOpenEvent *__qt_this = new(__qtjambi_ptr) QFileOpenEvent_shell(__qt_file0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QFileOpenEvent(QUrl)
void __qt_construct_QFileOpenEvent_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QFileOpenEvent(QUrl)")
    jobject url0 = __java_arguments[0].l;
    const QUrl& __qt_url0 = qtjambi_cast<const QUrl& >(__jni_env, url0);
    QFileOpenEvent *__qt_this = new(__qtjambi_ptr) QFileOpenEvent_shell(__qt_url0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QFileOpenEvent_shell
void __qt_destruct_QFileOpenEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QFileOpenEvent")
    reinterpret_cast<QFileOpenEvent_shell*>(ptr)->~QFileOpenEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QFileOpenEvent::QFileOpenEvent(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QFileOpenEvent_initialize_1native__Lio_qt_gui_QFileOpenEvent_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jstring file0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QFileOpenEvent::QFileOpenEvent(QString)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = file0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QFileOpenEvent_0, sizeof(QFileOpenEvent_shell), typeid(QFileOpenEvent), true, &deleter_QFileOpenEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QFileOpenEvent::QFileOpenEvent(QUrl)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QFileOpenEvent_initialize_1native__Lio_qt_gui_QFileOpenEvent_2Lio_qt_core_QUrl_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject url0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QFileOpenEvent::QFileOpenEvent(QUrl)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = url0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QFileOpenEvent_1, sizeof(QFileOpenEvent_shell), typeid(QFileOpenEvent), true, &deleter_QFileOpenEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QFileOpenEvent::file()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QFileOpenEvent_file_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QFileOpenEvent *__qt_this = QtJambiAPI::objectFromNativeId<QFileOpenEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QFileOpenEvent::file()const", __qt_this)
        QString __qt_return_value = __qt_this->file();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QFileOpenEvent::openFile(QFile&,QIODevice::OpenMode)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QFileOpenEvent_openFile_1native_1ref_1QFile_1QIODevice_1OpenMode_1constfct__JJI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID file0,
 jint flags1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QFileOpenEvent *__qt_this = QtJambiAPI::objectFromNativeId<QFileOpenEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QFileOpenEvent::openFile(QFile&,QIODevice::OpenMode)const", __qt_this)
        QFile& __qt_file0 = QtJambiAPI::objectReferenceFromNativeId<QFile>(__jni_env, file0);
        QIODevice::OpenMode __qt_flags1 = qtjambi_cast<QIODevice::OpenMode>(__jni_env, flags1);
        __java_return_value = __qt_this->openFile(__qt_file0, QIODevice::OpenMode(__qt_flags1));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QFileOpenEvent::url()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QFileOpenEvent_url_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QFileOpenEvent *__qt_this = QtJambiAPI::objectFromNativeId<QFileOpenEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QFileOpenEvent::url()const", __qt_this)
        QUrl __qt_return_value = __qt_this->url();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QFileOpenEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QFileOpenEvent *__qt_this = QtJambiAPI::objectFromNativeId<QFileOpenEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QFileOpenEvent(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QFileOpenEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QFileOpenEvent>("QFileOpenEvent", "io/qt/gui/QFileOpenEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QFileOpenEvent, {
        ConstructorInfo(&__qt_construct_QFileOpenEvent_0, "Ljava/lang/String;")
       ,ConstructorInfo(&__qt_construct_QFileOpenEvent_1, "Lio/qt/core/QUrl;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QFileOpenEvent);
    registerSizeOfShell(typeId, sizeof(QFileOpenEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QFileOpenEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QFileOpenEvent_shell.cpp <==
#include "QFileOpenEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QFileOpenEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QFileOpenEvent")
    QFileOpenEvent *_ptr = reinterpret_cast<QFileOpenEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QFileOpenEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QFileOpenEvent_shell) ); }

jmethodID QFileOpenEvent_shell::__shell_javaMethod(int pos) const { return QFileOpenEvent_shell::__shell()->javaMethod(typeid(QFileOpenEvent), pos); }

// emitting (writeShellConstructor)
QFileOpenEvent_shell::QFileOpenEvent_shell(const QFileOpenEvent& other0)
    : QFileOpenEvent(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QFileOpenEvent::QFileOpenEvent_shell(const QFileOpenEvent& other0)", QFileOpenEvent_shell::__shell())
    QFileOpenEvent_shell::__shell()->constructed(typeid(QFileOpenEvent));
}

QFileOpenEvent_shell::QFileOpenEvent_shell(const QString& file0)
    : QFileOpenEvent(file0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QFileOpenEvent::QFileOpenEvent_shell(const QString& file0)", QFileOpenEvent_shell::__shell())
    QFileOpenEvent_shell::__shell()->constructed(typeid(QFileOpenEvent));
}

QFileOpenEvent_shell::QFileOpenEvent_shell(const QUrl& url0)
    : QFileOpenEvent(url0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QFileOpenEvent::QFileOpenEvent_shell(const QUrl& url0)", QFileOpenEvent_shell::__shell())
    QFileOpenEvent_shell::__shell()->constructed(typeid(QFileOpenEvent));
}

// emitting (writeShellDestructor)
QFileOpenEvent_shell::~QFileOpenEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QFileOpenEvent::~QFileOpenEvent()", QFileOpenEvent_shell::__shell())
    QFileOpenEvent_shell::__shell()->destructed(typeid(QFileOpenEvent));
}

void QFileOpenEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QFileOpenEvent_shell*>(ptr)->QFileOpenEvent_shell::__shell()->tryDeleteShell(typeid(QFileOpenEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QFileOpenEvent(QFileOpenEvent)
void __qt_construct_QFileOpenEvent_cref_QFileOpenEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QFileOpenEvent(QFileOpenEvent)")
    jobject other0 = __java_arguments[0].l;
    const QFileOpenEvent& __qt_other0 = qtjambi_cast<const QFileOpenEvent& >(__jni_env, other0);
    QFileOpenEvent *__qt_this = new(__qtjambi_ptr) QFileOpenEvent_shell(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QFileOpenEvent::QFileOpenEvent(QFileOpenEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QFileOpenEvent_initialize_1native__Lio_qt_gui_QFileOpenEvent_2Lio_qt_gui_QFileOpenEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QFileOpenEvent::QFileOpenEvent(QFileOpenEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QFileOpenEvent_cref_QFileOpenEvent, sizeof(QFileOpenEvent_shell), typeid(QFileOpenEvent), true, &deleter_QFileOpenEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QFileOpenEvent(QString)
void __qt_construct_QFileOpenEvent_cref_QString(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QFileOpenEvent(QString)")
    jstring file0 = static_cast<jstring>(__java_arguments[0].l);
    QString  __qt_file0 = qtjambi_cast<QString>(__jni_env, file0);
    QFileOpenEvent *__qt_this = new(__qtjambi_ptr) QFileOpenEvent_shell(__qt_file0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QFileOpenEvent::QFileOpenEvent(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QFileOpenEvent_initialize_1native__Lio_qt_gui_QFileOpenEvent_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jstring file0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QFileOpenEvent::QFileOpenEvent(QString)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = file0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QFileOpenEvent_cref_QString, sizeof(QFileOpenEvent_shell), typeid(QFileOpenEvent), true, &deleter_QFileOpenEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QFileOpenEvent(QUrl)
void __qt_construct_QFileOpenEvent_cref_QUrl(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QFileOpenEvent(QUrl)")
    jobject url0 = __java_arguments[0].l;
    const QUrl& __qt_url0 = qtjambi_cast<const QUrl& >(__jni_env, url0);
    QFileOpenEvent *__qt_this = new(__qtjambi_ptr) QFileOpenEvent_shell(__qt_url0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QFileOpenEvent::QFileOpenEvent(QUrl)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QFileOpenEvent_initialize_1native__Lio_qt_gui_QFileOpenEvent_2Lio_qt_core_QUrl_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject url0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QFileOpenEvent::QFileOpenEvent(QUrl)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = url0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QFileOpenEvent_cref_QUrl, sizeof(QFileOpenEvent_shell), typeid(QFileOpenEvent), true, &deleter_QFileOpenEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QFileOpenEvent_shell
void __qt_destruct_QFileOpenEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QFileOpenEvent")
    reinterpret_cast<QFileOpenEvent_shell*>(ptr)->~QFileOpenEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QFileOpenEvent::file()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QFileOpenEvent_file_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QFileOpenEvent *__qt_this = QtJambiAPI::objectFromNativeId<QFileOpenEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QFileOpenEvent::file()const", __qt_this)
        QString __qt_return_value = __qt_this->file();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QFileOpenEvent::openFile(QFile&,QIODevice::OpenMode)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QFileOpenEvent_openFile_1native_1ref_1QFile_1QIODevice_1OpenMode_1constfct__JJI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID file0,
 jint flags1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QFileOpenEvent *__qt_this = QtJambiAPI::objectFromNativeId<QFileOpenEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QFileOpenEvent::openFile(QFile&,QIODevice::OpenMode)const", __qt_this)
        QFile& __qt_file0 = QtJambiAPI::objectReferenceFromNativeId<QFile>(__jni_env, file0);
        QIODevice::OpenMode __qt_flags1 = qtjambi_cast<QIODevice::OpenMode>(__jni_env, flags1);
        __java_return_value = __qt_this->openFile(__qt_file0, QIODevice::OpenMode(__qt_flags1));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QFileOpenEvent::url()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QFileOpenEvent_url_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QFileOpenEvent *__qt_this = QtJambiAPI::objectFromNativeId<QFileOpenEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QFileOpenEvent::url()const", __qt_this)
        QUrl __qt_return_value = __qt_this->url();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QFileOpenEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QFileOpenEvent *__qt_this = QtJambiAPI::objectFromNativeId<QFileOpenEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QFileOpenEvent(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QFileOpenEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QFileOpenEvent>("QFileOpenEvent", "io/qt/gui/QFileOpenEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QFileOpenEvent, {
        ConstructorInfo(&__qt_construct_QFileOpenEvent_cref_QFileOpenEvent, "Lio/qt/gui/QFileOpenEvent;")
       ,ConstructorInfo(&__qt_construct_QFileOpenEvent_cref_QString, "Ljava/lang/String;")
       ,ConstructorInfo(&__qt_construct_QFileOpenEvent_cref_QUrl, "Lio/qt/core/QUrl;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QFileOpenEvent);
    registerSizeOfShell(typeId, sizeof(QFileOpenEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QFileOpenEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
